<?php
declare(strict_types=1);

namespace Catequil\User\Model;

use Doctrine\DBAL\Types\Types;
use Doctrine\ORM\Mapping\Column;
use Doctrine\ORM\Mapping\Entity;
use Doctrine\ORM\Mapping\GeneratedValue;
use Doctrine\ORM\Mapping\Id;
use Doctrine\ORM\Mapping\Table;
use Laminas\Crypt\Password\Bcrypt;

/**
 * Class User
 *
 * @package Catequil\User\Model
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/oktan-nautika/catequil-user
 */
#[Entity]
#[Table('users', options: ['collate' => 'utf8mb4_croatian_ci'])]
class User implements UserInterface
{
    //<editor-fold desc="Entity Fields">

    #[Id]
    #[GeneratedValue('AUTO')]
    #[Column(type: Types::BIGINT, options: ['unsigned' => true])]
    protected int $id = 0;
    #[Column('email', Types::STRING, 191, unique: true)]
    protected string $emailAddress = '';
    #[Column(type: Types::STRING)]
    protected string $password = '';
    #[Column(type: Types::STRING)]
    protected string $name = '';

    //</editor-fold>
    //<editor-fold desc="Getters & Setters">

    public function getEmailAddress(): string
    {
        return $this->emailAddress;
    }

    public function getName(): string
    {
        return $this->name;
    }

    //</editor-fold>
    //<editor-fold desc="Actions">

    public function checkPassword(string $password): bool
    {
        $crypt = new Bcrypt();
        return $crypt->verify($password, $this->password);
    }

    public function setPassword(string $password): void
    {
        $crypt = new Bcrypt();
        $this->password = $crypt->create($password);
    }

    //</editor-fold>
}